@@ -8,6 +8,12 @@
 #include <QOrganizerTodo>
 #include <QXmlStreamReader>
 #include <QNetworkReply>
+#include <QGeoPositionInfo>
+
+
+#include <QDeclarativeView>
+#include <QDeclarativeItem>
+#include <QDeclarativeEngine>
 
 QTM_USE_NAMESPACE
 
@@ -23,6 +29,8 @@ public:
     explicit NewTaskDialog(QWidget *parent = 0);
     ~NewTaskDialog();
     QOrganizerTodo todo;
+    QGeoPositionInfo cur_pos;
+    QDeclarativeView *map_view;
     void setTodo(const QOrganizerTodo &todo);
     void on_buttonBox_accepted1();
 
@@ -47,6 +55,10 @@ private slots:
 
     void on_dateEdit_dateChanged(const QDate &date);
 
+    void on_here_clicked();
+
+    void on_pushButton_clicked();
+
 private:
     Ui::NewTaskDialog *ui;
     QXmlStreamReader xml;
